@@ -234,7 +234,7 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.15'
+__version__ = '0.1.16'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -273,6 +273,20 @@ def anchor_points(radius: float, anchor_x: float, anchor_y: float, anchor_dir: s
             )
 
 
+def help_id_has_translation(help_id: str) -> Tuple[Optional[Union[str, Dict[str, str]]], str]:
+    """ check if a help text exists for the passed help id.
+
+    :param help_id:         help id to check if a translation/help texts exists.
+    :return:                tuple of translation text (if help text exists) and maybe shortened help id(removed detail).
+    """
+    trans_text_or_dict = translation(help_id)
+    short_help_id = help_id
+    if not trans_text_or_dict and FLOW_KEY_SEP in help_id:
+        short_help_id = help_id[:help_id.index(FLOW_KEY_SEP)]  # remove detail (e.g. flow key or app state value)
+        trans_text_or_dict = translation(short_help_id)
+    return trans_text_or_dict, short_help_id
+
+
 def layout_ps_hints(wid_x: float, wid_y, wid_width, wid_height, win_width, win_height) -> Dict[str, Union[str, float]]:
     """ recalculate anchor and max width/height on change of widget pos/size or window size.
 
@@ -359,6 +373,8 @@ class HelpAppBase(MainAppBase, ABC):
     help_activator: Any = None          #: help mode de-/activator button widget
     help_layout: Optional[Any] = None   #: container/popup/dropdown/window widget in active help mode else None
 
+    _next_help_id: str = ''             #: last app state or flow change for to show help text on help mode activation
+
     @abstractmethod
     def ensure_top_most_z_index(self, widget: Any):
         """ ensure visibility of the passed widget to be the top most in the z index/order.
@@ -428,15 +444,18 @@ class HelpAppBase(MainAppBase, ABC):
         :param changed:         False before change of the app state, pass True if app state got just/already changed.
         :return:                True if help mode and layout is active and found target widget is locked, else False.
         """
-        hlw = self.help_layout
-        if hlw is None:
-            return False            # inactive help layout
-
-        state_name = help_vars['state_name']
-        if state_name in IGNORED_HELP_STATES:
+        state_name = help_vars.get('state_name')
+        if not state_name or state_name in IGNORED_HELP_STATES:
             return False
 
         help_id = self.help_app_state_id(state_name)
+
+        hlw = self.help_layout
+        if hlw is None:
+            if help_id_has_translation(help_id)[0]:
+                self._next_help_id = help_id
+            return False            # inactive help layout
+
         ret = self.help_display(help_id, help_vars, key_suffix='after' if changed else '')
         if help_id == self.displayed_help_id and not changed:
             ret = False             # allow to execute app state change
@@ -464,12 +483,7 @@ class HelpAppBase(MainAppBase, ABC):
         :param must_have:       pass True for to display error help text and console output if no help text exists.
         :return:                True if help text got found and displayed.
         """
-        has_trans = translation(help_id)
-        short_help_id = help_id
-        if not has_trans and FLOW_KEY_SEP in help_id:
-            short_help_id = help_id[:help_id.index(FLOW_KEY_SEP)]  # remove detail (e.g. flow key or app state value)
-            has_trans = translation(short_help_id)
-
+        has_trans, short_help_id = help_id_has_translation(help_id)
         if not has_trans:
             if not must_have:
                 return False
@@ -481,7 +495,7 @@ class HelpAppBase(MainAppBase, ABC):
             key_suffix = ''
             self.play_beep()
         elif key_suffix == 'after' and 'next_help_id' in has_trans:
-            help_id = short_help_id = has_trans['next_help_id']
+            help_id = short_help_id = has_trans['next_help_id']     # type: ignore # silly mypy, Pycharm is more clever
             key_suffix = ''
 
         hlw: Any = self.help_layout
@@ -503,15 +517,18 @@ class HelpAppBase(MainAppBase, ABC):
         :param changed:         False before change to new flow, pass True if flow got changed already.
         :return:                True if help layout is active and found target widget is locked, else False.
         """
-        hlw = self.help_layout
-        if hlw is None:
-            return False            # inactive help layout
-
-        nfi = help_vars['new_flow_id']
-        if nfi in IGNORED_HELP_FLOWS:
+        nfi = help_vars.get('new_flow_id')
+        if not nfi or nfi in IGNORED_HELP_FLOWS:
             return False
 
         help_id = self.help_flow_id(nfi)
+
+        hlw = self.help_layout
+        if hlw is None:
+            if help_id_has_translation(help_id)[0]:
+                self._next_help_id = help_id
+            return False            # inactive help layout
+
         ret = self.help_display(help_id, help_vars, key_suffix='after' if changed else '', must_have=not changed)
         if help_id == self.displayed_help_id and not changed:
             ret = False             # allow to execute flow change of currently explained flow button
@@ -533,6 +550,25 @@ class HelpAppBase(MainAppBase, ABC):
             return hid[len(HELP_ID_PREFIX_FLOW):]
         return ''
 
+    def help_target_and_id(self, help_vars: Dict[str, Any]) -> Tuple[Any, str]:
+        """ find help widget/target and help id on help mode activation.
+
+        :param help_vars:       optional help vars.
+        :return:                tuple of help target widget and help id.
+        """
+        activator = self.help_activator
+        if self._next_help_id:
+            help_id = self._next_help_id
+        elif self.flow_id:
+            help_id = self.help_flow_id(self.flow_id)
+        else:
+            return activator, ''
+
+        target = self.help_widget(help_id, help_vars)
+        if target is activator:
+            help_id = ''
+        return target, help_id
+
     def help_variables(self, help_vars: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
         """ determine globals and extend help vars for help text evaluation/translation
 
